@@ -1731,9 +1731,10 @@ sub initialize_code {
 
 sub base2package {
   my $self = shift;
+  return $self->{base2package} if exists $self->{base2package};
   (my $package = overload::StrVal($self)) =~ s/[^a-z0-9A-Z_]/_/g;
   $package     =~ s/^[^a-zA-Z_]/_/g;
-  $package;
+  return $self->{base2package} = $package;
 }
 
 sub split_group {
